==> JabberGuestSDK-iOS-10.0.1.278.zip: JabberGuestSDK-iOS-10.0.1.278/docs/api/search/all_63.js <==
var searchData=
[
  ['callbarview_3aclickedbutton_3a',['callBarView:clickedButton:',['../protocol_c_j_guest_call_bar_view_delegate-p.html#accf7c7bba37dd65d224d05a94948d6e8',1,'CJGuestCallBarViewDelegate-p']]],
  ['callbarviewdiddismisskeypad_3a',['callBarViewDidDismissKeypad:',['../protocol_c_j_guest_call_bar_view_delegate-p.html#a9277690dcf0be3c9d3591b91fb7e5371',1,'CJGuestCallBarViewDelegate-p']]],
  ['callbarviewdidpresentkeypad_3a',['callBarViewDidPresentKeypad:',['../protocol_c_j_guest_call_bar_view_delegate-p.html#afde5bffa87b44ed36ff00a14f0d6f2cf',1,'CJGuestCallBarViewDelegate-p']]],
  ['callfinishedforcallcontroller_3a',['callFinishedForCallController:',['../protocol_c_j_guest_call_view_controller_delegate-p.html#a8b46f223dc8b9ac5d1dafde268b4e155',1,'CJGuestCallViewControllerDelegate-p']]],
  ['callstate',['callState',['../class_c_j_guest_call.html#ae44209a5f5c35e188119fd513e0039cb',1,'CJGuestCall']]],
  ['captureorientation',['captureOrientation',['../class_c_j_guest_call.html#afcdb8c26d23187af673ad21ff4c1b6c3',1,'CJGuestCall']]],
  ['cjguestaudiostatistics',['CJGuestAudioStatistics',['../class_c_j_guest_audio_statistics.html',1,'']]],
  ['cjguestblanksdperror',['CJGuestBlankSdpError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a4d1989b2bcb0099463de9b680572e324',1,'CJGuestCall.h']]],
  ['cjguestblanksipurierror',['CJGuestBlankSipUriError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a5825b266edbf32082b87938eb30bfff7',1,'CJGuestCall.h']]],
  ['cjguestcall',['CJGuestCall',['../class_c_j_guest_call.html',1,'']]],
  ['cjguestcallaudioinstatenotification',['CJGuestCallAudioInStateNotification',['../group__cjgnotifications.html#gad55bf574a8c0db17d9843e4cb8e94e1e',1,'CJGuestCallAudioInStateNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gad55bf574a8c0db17d9843e4cb8e94e1e',1,'CJGuestCallAudioInStateNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallaudiooutstatenotification',['CJGuestCallAudioOutStateNotification',['../group__cjgnotifications.html#ga9afcaf8a4cb31e4aa8c8f4cce0162480',1,'CJGuestCallAudioOutStateNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#ga9afcaf8a4cb31e4aa8c8f4cce0162480',1,'CJGuestCallAudioOutStateNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallbarbuttonoption',['CJGuestCallBarButtonOption',['../class_c_j_guest_call_bar_view.html#aab11c8cedd3666cf367259b3f6c01b73',1,'CJGuestCallBarView']]],
  ['cjguestcallbarbuttontype',['CJGuestCallBarButtonType',['../class_c_j_guest_call_bar_view.html#aeaf24fb62ca2c0edb8e06f13fc4f9c92',1,'CJGuestCallBarView']]],
  ['cjguestcallbarview',['CJGuestCallBarView',['../class_c_j_guest_call_bar_view.html',1,'']]],
  ['cjguestcallbarviewdelegate_2dp',['CJGuestCallBarViewDelegate-p',['../protocol_c_j_guest_call_bar_view_delegate-p.html',1,'']]],
  ['cjguestcallcameraswitchednotification',['CJGuestCallCameraSwitchedNotification',['../group__cjgnotifications.html#gaccd8c3b1475986028ae6387b31ccf6a5',1,'CJGuestCallCameraSwitchedNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gaccd8c3b1475986028ae6387b31ccf6a5',1,'CJGuestCallCameraSwitchedNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallerrorkey',['CJGuestCallErrorKey',['../group__cjgnotifications.html#ga11fbf19833d62a646665dc73abad1215',1,'CJGuestCallErrorKey():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#ga11fbf19833d62a646665dc73abad1215',1,'CJGuestCallErrorKey():&#160;CJGuestCall.mm']]],
  ['cjguestcallerrornotification',['CJGuestCallErrorNotification',['../group__cjgnotifications.html#gaf659c10dc7fe65ce7995751d5a3aa8a6',1,'CJGuestCallErrorNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gaf659c10dc7fe65ce7995751d5a3aa8a6',1,'CJGuestCallErrorNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallkeypadbuttontype',['CJGuestCallKeypadButtonType',['../group__keypadbuttons.html#ga2bc7e8cd24dfb590b04c0b19e7639bbc',1,'CJGuestCallKeypadView.h']]],
  ['cjguestcallkeypadview',['CJGuestCallKeypadView',['../class_c_j_guest_call_keypad_view.html',1,'']]],
  ['cjguestcallkeypadviewdelegate_2dp',['CJGuestCallKeypadViewDelegate-p',['../protocol_c_j_guest_call_keypad_view_delegate-p.html',1,'']]],
  ['cjguestcallorientationnotification',['CJGuestCallOrientationNotification',['../group__cjgnotifications.html#ga312c98d138ceaa08e0de2aa660f06f91',1,'CJGuestCallOrientationNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#ga312c98d138ceaa08e0de2aa660f06f91',1,'CJGuestCallOrientationNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallremotevideoresolutionnotification',['CJGuestCallRemoteVideoResolutionNotification',['../group__cjgnotifications.html#gaa3741e7dc295823dd7fb635d90a3c46b',1,'CJGuestCallRemoteVideoResolutionNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gaa3741e7dc295823dd7fb635d90a3c46b',1,'CJGuestCallRemoteVideoResolutionNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallselfvideoresolutionnotification',['CJGuestCallSelfVideoResolutionNotification',['../group__cjgnotifications.html#gabfbc8a4891610ad1a4a456121510dffa',1,'CJGuestCallSelfVideoResolutionNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gabfbc8a4891610ad1a4a456121510dffa',1,'CJGuestCallSelfVideoResolutionNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallselfview',['CJGuestCallSelfView',['../class_c_j_guest_call_self_view.html',1,'']]],
  ['cjguestcallsentdtmfnotification',['CJGuestCallSentDTMFNotification',['../group__cjgnotifications.html#gad62d3bc99623b679ee050c6fd1f0de6d',1,'CJGuestCallSentDTMFNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gad62d3bc99623b679ee050c6fd1f0de6d',1,'CJGuestCallSentDTMFNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallstatechangenotification',['CJGuestCallStateChangeNotification',['../group__cjgnotifications.html#ga9b53b4c0fbbc72b752c984fa7e71ab3b',1,'CJGuestCallStateChangeNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#ga9b53b4c0fbbc72b752c984fa7e71ab3b',1,'CJGuestCallStateChangeNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallstatetype',['CJGuestCallStateType',['../class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6',1,'CJGuestCall']]],
  ['cjguestcallvideoinstatenotification',['CJGuestCallVideoInStateNotification',['../group__cjgnotifications.html#gadc1ec01afdc1278eefa9ef7977a12b9f',1,'CJGuestCallVideoInStateNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gadc1ec01afdc1278eefa9ef7977a12b9f',1,'CJGuestCallVideoInStateNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallvideooutstatenotification',['CJGuestCallVideoOutStateNotification',['../group__cjgnotifications.html#gae50e53e659610c76112e37c761f9b1d5',1,'CJGuestCallVideoOutStateNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gae50e53e659610c76112e37c761f9b1d5',1,'CJGuestCallVideoOutStateNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallviewcontroller',['CJGuestCallViewController',['../class_c_j_guest_call_view_controller.html',1,'']]],
  ['cjguestcallviewcontrollerdelegate_2dp',['CJGuestCallViewControllerDelegate-p',['../protocol_c_j_guest_call_view_controller_delegate-p.html',1,'']]],
  ['cjguestcodecstatistics',['CJGuestCodecStatistics',['../class_c_j_guest_codec_statistics.html',1,'']]],
  ['cjguesterrorcode',['CJGuestErrorCode',['../group__cjgerrors.html#ga71aeb3d263635c8304359bc1e800ef06',1,'CJGuestCall.h']]],
  ['cjguesthttperror',['CJGuestHttpError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a7ab38759486baf3594151889ce8e3856',1,'CJGuestCall.h']]],
  ['cjguestinvalidcallstateerror',['CJGuestInvalidCallStateError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a9891809dcd0ccc6acdc394c4c6861b68',1,'CJGuestCall.h']]],
  ['cjguestinvalidcertalertviewdelegate_2dp',['CJGuestInvalidCertAlertViewDelegate-p',['../protocol_c_j_guest_invalid_cert_alert_view_delegate-p.html',1,'']]],
  ['cjguestinvalidcertcallback_2dp',['CJGuestInvalidCertCallback-p',['../protocol_c_j_guest_invalid_cert_callback-p.html',1,'']]],
  ['cjguestinvalidcertdelegate_2dp',['CJGuestInvalidCertDelegate-p',['../protocol_c_j_guest_invalid_cert_delegate-p.html',1,'']]],
  ['cjguestinvalidsipurierror',['CJGuestInvalidSipUriError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06adb44cc818c96627c4989ed3aedbc1f8a',1,'CJGuestCall.h']]],
  ['cjguestlinkdisablederror',['CJGuestLinkDisabledError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a013ed407d6684d095bcac27eae212663',1,'CJGuestCall.h']]],
  ['cjguestlinkexpirederror',['CJGuestLinkExpiredError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06af0f845c809cf122037e4eceaeb96bcb8',1,'CJGuestCall.h']]],
  ['cjguestlinknotfounderror',['CJGuestLinkNotFoundError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06ade4c0308a1f9851e12cf88d2624ff3a2',1,'CJGuestCall.h']]],
  ['cjguestlinknotvalidyeterror',['CJGuestLinkNotValidYetError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06ac3ce635db9eb2f0056f412a18941ec34',1,'CJGuestCall.h']]],
  ['cjguestmediagatewayallocationfailederror',['CJGuestMediaGatewayAllocationFailedError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a294101d86ad00a479aacc1ccf2122570',1,'CJGuestCall.h']]],
  ['cjguestmediagatewayicefailederror',['CJGuestMediaGatewayIceFailedError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a1255f37867e6483ca1c007c70a82188e',1,'CJGuestCall.h']]],
  ['cjguestmediagatewayundefinederror',['CJGuestMediaGatewayUndefinedError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06ac508974924847f6f3f614abfa267d834',1,'CJGuestCall.h']]],
  ['cjguestmediastatistics',['CJGuestMediaStatistics',['../class_c_j_guest_media_statistics.html',1,'']]],
  ['cjguestmutestatetype',['CJGuestMuteStateType',['../class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cd',1,'CJGuestCall']]],
  ['cjguestneterror',['CJGuestNetError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06aa2456556473247595f9ac30be42d8f95',1,'CJGuestCall.h']]],
  ['cjguestroapexceptionerror',['CJGuestRoapExceptionError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a4feb4bc011051941c54309e89618db46',1,'CJGuestCall.h']]],
  ['cjguestsipconfigurationerror',['CJGuestSipConfigurationError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06ae543c640941516a7e383163c41cb8362',1,'CJGuestCall.h']]],
  ['cjguestsipendpointbusyerror',['CJGuestSipEndpointBusyError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a0b1477481e52c067510364d0e1042ff3',1,'CJGuestCall.h']]],
  ['cjguestsiperror',['CJGuestSipError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a955636f9c07c073d29d62b40a05611ee',1,'CJGuestCall.h']]],
  ['cjguestturncredacquirefailederror',['CJGuestTurnCredAcquireFailedError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06aca44dc42028feffaa7d481c2c93c7be1',1,'CJGuestCall.h']]],
  ['cjguestunknownerror',['CJGuestUnknownError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06aa034591de4363a1cb5301b155f55eda5',1,'CJGuestCall.h']]],
  ['cjguestvideolicense',['CJGuestVideoLicense',['../class_c_j_guest_video_license.html',1,'']]],
  ['cjguestvideostatistics',['CJGuestVideoStatistics',['../class_c_j_guest_video_statistics.html',1,'']]],
  ['clockrate',['clockRate',['../class_c_j_guest_codec_statistics.html#a1cac466db7db710adc4bef658dfd2df8',1,'CJGuestCodecStatistics']]],
  ['configurefromurl_3a',['configureFromURL:',['../class_c_j_guest_call_view_controller.html#a40f6e77c9d024a023fdb472ee6171702',1,'CJGuestCallViewController']]]
];

==> JabberGuestSDK-iOS-10.5.2.415.zip: JabberGuestSDK-iOS-10.5.2.415/docs/api/search/all_63.js <==
var searchData=
[
  ['callbarbuttonsize',['callBarButtonSize',['../class_c_j_guest_call_bar_view.html#af6168cd7dd02cb63fdbfe81b8a6fdb9b',1,'CJGuestCallBarView']]],
  ['callbarview_3aclickedbutton_3a',['callBarView:clickedButton:',['../protocol_c_j_guest_call_bar_view_delegate-p.html#accf7c7bba37dd65d224d05a94948d6e8',1,'CJGuestCallBarViewDelegate-p']]],
  ['callbarviewdiddismisskeypad_3a',['callBarViewDidDismissKeypad:',['../protocol_c_j_guest_call_bar_view_delegate-p.html#a9277690dcf0be3c9d3591b91fb7e5371',1,'CJGuestCallBarViewDelegate-p']]],
  ['callbarviewdidpresentkeypad_3a',['callBarViewDidPresentKeypad:',['../protocol_c_j_guest_call_bar_view_delegate-p.html#afde5bffa87b44ed36ff00a14f0d6f2cf',1,'CJGuestCallBarViewDelegate-p']]],
  ['callfinishedforcallcontroller_3a',['callFinishedForCallController:',['../protocol_c_j_guest_call_view_controller_delegate-p.html#a8b46f223dc8b9ac5d1dafde268b4e155',1,'CJGuestCallViewControllerDelegate-p']]],
  ['callstate',['callState',['../class_c_j_guest_call.html#ae44209a5f5c35e188119fd513e0039cb',1,'CJGuestCall']]],
  ['captureorientation',['captureOrientation',['../class_c_j_guest_call.html#afcdb8c26d23187af673ad21ff4c1b6c3',1,'CJGuestCall']]],
  ['cjguestaudiostatistics',['CJGuestAudioStatistics',['../class_c_j_guest_audio_statistics.html',1,'']]],
  ['cjguestblanksdperror',['CJGuestBlankSdpError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a4d1989b2bcb0099463de9b680572e324',1,'CJGuestCall.h']]],
  ['cjguestblanksipurierror',['CJGuestBlankSipUriError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a5825b266edbf32082b87938eb30bfff7',1,'CJGuestCall.h']]],
  ['cjguestcall',['CJGuestCall',['../class_c_j_guest_call.html',1,'']]],
  ['cjguestcallaudioinstatenotification',['CJGuestCallAudioInStateNotification',['../group__cjgnotifications.html#gad55bf574a8c0db17d9843e4cb8e94e1e',1,'CJGuestCallAudioInStateNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gad55bf574a8c0db17d9843e4cb8e94e1e',1,'CJGuestCallAudioInStateNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallaudiooutstatenotification',['CJGuestCallAudioOutStateNotification',['../group__cjgnotifications.html#ga9afcaf8a4cb31e4aa8c8f4cce0162480',1,'CJGuestCallAudioOutStateNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#ga9afcaf8a4cb31e4aa8c8f4cce0162480',1,'CJGuestCallAudioOutStateNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallbarbuttonoption',['CJGuestCallBarButtonOption',['../class_c_j_guest_call_bar_view.html#aab11c8cedd3666cf367259b3f6c01b73',1,'CJGuestCallBarView']]],
  ['cjguestcallbarbuttontype',['CJGuestCallBarButtonType',['../class_c_j_guest_call_bar_view.html#aeaf24fb62ca2c0edb8e06f13fc4f9c92',1,'CJGuestCallBarView']]],
  ['cjguestcallbarview',['CJGuestCallBarView',['../class_c_j_guest_call_bar_view.html',1,'']]],
  ['cjguestcallbarviewdelegate_2dp',['CJGuestCallBarViewDelegate-p',['../protocol_c_j_guest_call_bar_view_delegate-p.html',1,'']]],
  ['cjguestcallcameraswitchednotification',['CJGuestCallCameraSwitchedNotification',['../group__cjgnotifications.html#gaccd8c3b1475986028ae6387b31ccf6a5',1,'CJGuestCallCameraSwitchedNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gaccd8c3b1475986028ae6387b31ccf6a5',1,'CJGuestCallCameraSwitchedNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallerrorkey',['CJGuestCallErrorKey',['../group__cjgnotifications.html#ga11fbf19833d62a646665dc73abad1215',1,'CJGuestCallErrorKey():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#ga11fbf19833d62a646665dc73abad1215',1,'CJGuestCallErrorKey():&#160;CJGuestCall.mm']]],
  ['cjguestcallerrornotification',['CJGuestCallErrorNotification',['../group__cjgnotifications.html#gaf659c10dc7fe65ce7995751d5a3aa8a6',1,'CJGuestCallErrorNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gaf659c10dc7fe65ce7995751d5a3aa8a6',1,'CJGuestCallErrorNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallkeypadbuttontype',['CJGuestCallKeypadButtonType',['../group__keypadbuttons.html#ga2bc7e8cd24dfb590b04c0b19e7639bbc',1,'CJGuestCallKeypadView.h']]],
  ['cjguestcallkeypadview',['CJGuestCallKeypadView',['../class_c_j_guest_call_keypad_view.html',1,'']]],
  ['cjguestcallkeypadviewdelegate_2dp',['CJGuestCallKeypadViewDelegate-p',['../protocol_c_j_guest_call_keypad_view_delegate-p.html',1,'']]],
  ['cjguestcallorientationnotification',['CJGuestCallOrientationNotification',['../group__cjgnotifications.html#ga312c98d138ceaa08e0de2aa660f06f91',1,'CJGuestCallOrientationNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#ga312c98d138ceaa08e0de2aa660f06f91',1,'CJGuestCallOrientationNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallremotevideoresolutionnotification',['CJGuestCallRemoteVideoResolutionNotification',['../group__cjgnotifications.html#gaa3741e7dc295823dd7fb635d90a3c46b',1,'CJGuestCallRemoteVideoResolutionNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gaa3741e7dc295823dd7fb635d90a3c46b',1,'CJGuestCallRemoteVideoResolutionNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallselfvideoresolutionnotification',['CJGuestCallSelfVideoResolutionNotification',['../group__cjgnotifications.html#gabfbc8a4891610ad1a4a456121510dffa',1,'CJGuestCallSelfVideoResolutionNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gabfbc8a4891610ad1a4a456121510dffa',1,'CJGuestCallSelfVideoResolutionNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallselfview',['CJGuestCallSelfView',['../class_c_j_guest_call_self_view.html',1,'']]],
  ['cjguestcallsentdtmfnotification',['CJGuestCallSentDTMFNotification',['../group__cjgnotifications.html#gad62d3bc99623b679ee050c6fd1f0de6d',1,'CJGuestCallSentDTMFNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gad62d3bc99623b679ee050c6fd1f0de6d',1,'CJGuestCallSentDTMFNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallstatechangenotification',['CJGuestCallStateChangeNotification',['../group__cjgnotifications.html#ga9b53b4c0fbbc72b752c984fa7e71ab3b',1,'CJGuestCallStateChangeNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#ga9b53b4c0fbbc72b752c984fa7e71ab3b',1,'CJGuestCallStateChangeNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallstatetype',['CJGuestCallStateType',['../class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6',1,'CJGuestCall']]],
  ['cjguestcallvideoinstatenotification',['CJGuestCallVideoInStateNotification',['../group__cjgnotifications.html#gadc1ec01afdc1278eefa9ef7977a12b9f',1,'CJGuestCallVideoInStateNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gadc1ec01afdc1278eefa9ef7977a12b9f',1,'CJGuestCallVideoInStateNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallvideooutstatenotification',['CJGuestCallVideoOutStateNotification',['../group__cjgnotifications.html#gae50e53e659610c76112e37c761f9b1d5',1,'CJGuestCallVideoOutStateNotification():&#160;CJGuestCall.mm'],['../group__cjgnotifications.html#gae50e53e659610c76112e37c761f9b1d5',1,'CJGuestCallVideoOutStateNotification():&#160;CJGuestCall.mm']]],
  ['cjguestcallviewcontroller',['CJGuestCallViewController',['../class_c_j_guest_call_view_controller.html',1,'']]],
  ['cjguestcallviewcontrollerdelegate_2dp',['CJGuestCallViewControllerDelegate-p',['../protocol_c_j_guest_call_view_controller_delegate-p.html',1,'']]],
  ['cjguestcodecstatistics',['CJGuestCodecStatistics',['../class_c_j_guest_codec_statistics.html',1,'']]],
  ['cjguesterrorcode',['CJGuestErrorCode',['../group__cjgerrors.html#ga71aeb3d263635c8304359bc1e800ef06',1,'CJGuestCall.h']]],
  ['cjguesthttperror',['CJGuestHttpError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a7ab38759486baf3594151889ce8e3856',1,'CJGuestCall.h']]],
  ['cjguestinvalidcallstateerror',['CJGuestInvalidCallStateError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a9891809dcd0ccc6acdc394c4c6861b68',1,'CJGuestCall.h']]],
  ['cjguestinvalidcertalertviewdelegate_2dp',['CJGuestInvalidCertAlertViewDelegate-p',['../protocol_c_j_guest_invalid_cert_alert_view_delegate-p.html',1,'']]],
  ['cjguestinvalidcertcallback_2dp',['CJGuestInvalidCertCallback-p',['../protocol_c_j_guest_invalid_cert_callback-p.html',1,'']]],
  ['cjguestinvalidcertdelegate_2dp',['CJGuestInvalidCertDelegate-p',['../protocol_c_j_guest_invalid_cert_delegate-p.html',1,'']]],
  ['cjguestinvalidsipurierror',['CJGuestInvalidSipUriError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06adb44cc818c96627c4989ed3aedbc1f8a',1,'CJGuestCall.h']]],
  ['cjguestlinkdisablederror',['CJGuestLinkDisabledError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a013ed407d6684d095bcac27eae212663',1,'CJGuestCall.h']]],
  ['cjguestlinkexpirederror',['CJGuestLinkExpiredError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06af0f845c809cf122037e4eceaeb96bcb8',1,'CJGuestCall.h']]],
  ['cjguestlinknotfounderror',['CJGuestLinkNotFoundError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06ade4c0308a1f9851e12cf88d2624ff3a2',1,'CJGuestCall.h']]],
  ['cjguestlinknotvalidyeterror',['CJGuestLinkNotValidYetError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06ac3ce635db9eb2f0056f412a18941ec34',1,'CJGuestCall.h']]],
  ['cjguestmediagatewayallocationfailederror',['CJGuestMediaGatewayAllocationFailedError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a294101d86ad00a479aacc1ccf2122570',1,'CJGuestCall.h']]],
  ['cjguestmediagatewayicefailederror',['CJGuestMediaGatewayIceFailedError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a1255f37867e6483ca1c007c70a82188e',1,'CJGuestCall.h']]],
  ['cjguestmediagatewayundefinederror',['CJGuestMediaGatewayUndefinedError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06ac508974924847f6f3f614abfa267d834',1,'CJGuestCall.h']]],
  ['cjguestmediastatistics',['CJGuestMediaStatistics',['../class_c_j_guest_media_statistics.html',1,'']]],
  ['cjguestmutestatetype',['CJGuestMuteStateType',['../class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cd',1,'CJGuestCall']]],
  ['cjguestneterror',['CJGuestNetError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06aa2456556473247595f9ac30be42d8f95',1,'CJGuestCall.h']]],
  ['cjguestroapexceptionerror',['CJGuestRoapExceptionError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a4feb4bc011051941c54309e89618db46',1,'CJGuestCall.h']]],
  ['cjguestsipconfigurationerror',['CJGuestSipConfigurationError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06ae543c640941516a7e383163c41cb8362',1,'CJGuestCall.h']]],
  ['cjguestsipendpointbusyerror',['CJGuestSipEndpointBusyError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a0b1477481e52c067510364d0e1042ff3',1,'CJGuestCall.h']]],
  ['cjguestsiperror',['CJGuestSipError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06a955636f9c07c073d29d62b40a05611ee',1,'CJGuestCall.h']]],
  ['cjguestturncredacquirefailederror',['CJGuestTurnCredAcquireFailedError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06aca44dc42028feffaa7d481c2c93c7be1',1,'CJGuestCall.h']]],
  ['cjguestunknownerror',['CJGuestUnknownError',['../group__cjgerrors.html#gga71aeb3d263635c8304359bc1e800ef06aa034591de4363a1cb5301b155f55eda5',1,'CJGuestCall.h']]],
  ['cjguestvideolicense',['CJGuestVideoLicense',['../class_c_j_guest_video_license.html',1,'']]],
  ['cjguestvideostatistics',['CJGuestVideoStatistics',['../class_c_j_guest_video_statistics.html',1,'']]],
  ['clockrate',['clockRate',['../class_c_j_guest_codec_statistics.html#a1cac466db7db710adc4bef658dfd2df8',1,'CJGuestCodecStatistics']]],
  ['configurefromurl_3a',['configureFromURL:',['../class_c_j_guest_call_view_controller.html#a40f6e77c9d024a023fdb472ee6171702',1,'CJGuestCallViewController']]]
];
